@@ -125,27 +125,27 @@ namespace pika {
 
 #else    // DOXYGEN
 
-#include <pika/config.hpp>
-#include <pika/async_base/launch_policy.hpp>
-#include <pika/futures/future.hpp>
-#include <pika/futures/traits/acquire_future.hpp>
-#include <pika/futures/traits/detail/future_traits.hpp>
-#include <pika/futures/traits/future_access.hpp>
-#include <pika/futures/traits/future_traits.hpp>
-#include <pika/futures/traits/is_future.hpp>
-#include <pika/futures/traits/is_future_range.hpp>
-#include <pika/iterator_support/range.hpp>
-#include <pika/memory/intrusive_ptr.hpp>
-#include <pika/type_support/decay.hpp>
-#include <pika/type_support/unwrap_reference.hpp>
+# include <pika/config.hpp>
+# include <pika/async_base/launch_policy.hpp>
+# include <pika/futures/future.hpp>
+# include <pika/futures/traits/acquire_future.hpp>
+# include <pika/futures/traits/detail/future_traits.hpp>
+# include <pika/futures/traits/future_access.hpp>
+# include <pika/futures/traits/future_traits.hpp>
+# include <pika/futures/traits/is_future.hpp>
+# include <pika/futures/traits/is_future_range.hpp>
+# include <pika/iterator_support/range.hpp>
+# include <pika/memory/intrusive_ptr.hpp>
+# include <pika/type_support/decay.hpp>
+# include <pika/type_support/unwrap_reference.hpp>
 
-#include <algorithm>
-#include <cstddef>
-#include <iterator>
-#include <tuple>
-#include <type_traits>
-#include <utility>
-#include <vector>
+# include <algorithm>
+# include <cstddef>
+# include <iterator>
+# include <tuple>
+# include <type_traits>
+# include <utility>
+# include <vector>
 
 ///////////////////////////////////////////////////////////////////////////////
 namespace pika {
@@ -165,8 +165,7 @@ namespace pika {
             when_each_frame& operator=(when_each_frame&&) = delete;
 
             template <std::size_t I>
-            struct is_end
-              : std::integral_constant<bool, std::tuple_size<Tuple>::value == I>
+            struct is_end : std::integral_constant<bool, std::tuple_size<Tuple>::value == I>
             {
             };
 
@@ -193,8 +192,8 @@ namespace pika {
                 }
                 else
                 {
-                    using future_type = pika::detail::decay_unwrap_t<
-                        typename std::tuple_element<I, Tuple>::type>;
+                    using future_type =
+                        pika::detail::decay_unwrap_t<typename std::tuple_element<I, Tuple>::type>;
 
                     if constexpr (pika::traits::is_future_v<future_type> ||
                         pika::traits::is_ref_wrapped_future_v<future_type>)
@@ -203,16 +202,12 @@ namespace pika {
                     }
                     else
                     {
-                        static_assert(
-                            pika::traits::is_future_range_v<future_type> ||
-                                pika::traits::is_ref_wrapped_future_range_v<
-                                    future_type>,
+                        static_assert(pika::traits::is_future_range_v<future_type> ||
+                                pika::traits::is_ref_wrapped_future_range_v<future_type>,
                             "element must be future or range of futures");
 
-                        auto&& curr =
-                            pika::detail::unwrap_reference(std::get<I>(t_));
-                        await_range<I>(
-                            pika::util::begin(curr), pika::util::end(curr));
+                        auto&& curr = pika::detail::unwrap_reference(std::get<I>(t_));
+                        await_range<I>(pika::util::begin(curr), pika::util::end(curr));
                     }
                 }
             }
@@ -222,14 +217,12 @@ namespace pika {
             template <std::size_t I, typename Iter>
             void await_range(Iter&& next, Iter&& end)
             {
-                using future_type =
-                    typename std::iterator_traits<Iter>::value_type;
+                using future_type = typename std::iterator_traits<Iter>::value_type;
 
                 pika::intrusive_ptr<when_each_frame> this_(this);
                 for (/**/; next != end; ++next)
                 {
-                    auto next_future_data =
-                        traits::detail::get_shared_state(*next);
+                    auto next_future_data = traits::detail::get_shared_state(*next);
 
                     if (next_future_data && !next_future_data->is_ready())
                     {
@@ -242,11 +235,9 @@ namespace pika {
                             // re-evaluate it and continue to the next argument
                             // (if any).
                             next_future_data->set_on_completed(
-                                [this_ = PIKA_MOVE(this_),
-                                    next = PIKA_MOVE(next),
+                                [this_ = PIKA_MOVE(this_), next = PIKA_MOVE(next),
                                     end = PIKA_MOVE(end)]() mutable -> void {
-                                    this_->template await_range<I>(
-                                        PIKA_MOVE(next), PIKA_MOVE(end));
+                                    this_->template await_range<I>(PIKA_MOVE(next), PIKA_MOVE(end));
                                 });
 
                             // explicitly destruct iterators as those might
@@ -258,8 +249,7 @@ namespace pika {
                     }
 
                     // call supplied callback with or without index
-                    if constexpr (std::is_invocable_v<F, std::size_t,
-                                      future_type>)
+                    if constexpr (std::is_invocable_v<F, std::size_t, future_type>)
                     {
                         f_(count_, PIKA_MOVE(*next));
                     }
@@ -287,8 +277,8 @@ namespace pika {
             template <std::size_t I>
             PIKA_FORCEINLINE void await_future()
             {
-                using future_type = pika::detail::decay_unwrap_t<
-                    typename std::tuple_element<I, Tuple>::type>;
+                using future_type =
+                    pika::detail::decay_unwrap_t<typename std::tuple_element<I, Tuple>::type>;
 
                 pika::intrusive_ptr<when_each_frame> this_(this);
 
@@ -304,10 +294,9 @@ namespace pika {
                         // Attach a continuation to this future which will
                         // re-evaluate it and continue to the next argument
                         // (if any).
-                        next_future_data->set_on_completed(
-                            [this_ = PIKA_MOVE(this_)]() -> void {
-                                this_->template await_future<I>();
-                            });
+                        next_future_data->set_on_completed([this_ = PIKA_MOVE(this_)]() -> void {
+                            this_->template await_future<I>();
+                        });
 
                         return;
                     }
@@ -346,23 +335,20 @@ namespace pika {
     pika::future<void> when_each(F&& func, std::vector<Future>& lazy_values)
     {
         using argument_type = std::tuple<std::vector<Future>>;
-        using frame_type =
-            detail::when_each_frame<argument_type, std::decay_t<F>>;
+        using frame_type = detail::when_each_frame<argument_type, std::decay_t<F>>;
 
         std::vector<Future> values;
         values.reserve(lazy_values.size());
 
-        std::transform(lazy_values.begin(), lazy_values.end(),
-            std::back_inserter(values), traits::acquire_future_disp());
+        std::transform(lazy_values.begin(), lazy_values.end(), std::back_inserter(values),
+            traits::acquire_future_disp());
 
-        pika::intrusive_ptr<frame_type> p(
-            new frame_type(std::forward_as_tuple(PIKA_MOVE(values)),
-                PIKA_FORWARD(F, func), values.size()));
+        pika::intrusive_ptr<frame_type> p(new frame_type(
+            std::forward_as_tuple(PIKA_MOVE(values)), PIKA_FORWARD(F, func), values.size()));
 
         p->template do_await<0>();
 
-        return pika::traits::future_access<typename frame_type::type>::create(
-            PIKA_MOVE(p));
+        return pika::traits::future_access<typename frame_type::type>::create(PIKA_MOVE(p));
     }
 
     template <typename F, typename Future>
@@ -373,34 +359,28 @@ namespace pika {
     }
 
     template <typename F, typename Iterator,
-        typename Enable =
-            std::enable_if_t<pika::traits::is_iterator_v<Iterator>>>
+        typename Enable = std::enable_if_t<pika::traits::is_iterator_v<Iterator>>>
     pika::future<Iterator> when_each(F&& f, Iterator begin, Iterator end)
     {
-        using future_type =
-            typename lcos::detail::future_iterator_traits<Iterator>::type;
+        using future_type = typename lcos::detail::future_iterator_traits<Iterator>::type;
 
         std::vector<future_type> values;
         traits::detail::reserve_if_random_access_by_range(values, begin, end);
 
-        std::transform(begin, end, std::back_inserter(values),
-            traits::acquire_future_disp());
+        std::transform(begin, end, std::back_inserter(values), traits::acquire_future_disp());
 
         return pika::when_each(PIKA_FORWARD(F, f), values)
-            .then(pika::launch::sync,
-                [end = PIKA_MOVE(end)](pika::future<void> fut) -> Iterator {
-                    fut.get();    // rethrow exceptions, if any
-                    return end;
-                });
+            .then(pika::launch::sync, [end = PIKA_MOVE(end)](pika::future<void> fut) -> Iterator {
+                fut.get();    // rethrow exceptions, if any
+                return end;
+            });
     }
 
     template <typename F, typename Iterator,
-        typename Enable =
-            std::enable_if_t<pika::traits::is_iterator_v<Iterator>>>
+        typename Enable = std::enable_if_t<pika::traits::is_iterator_v<Iterator>>>
     pika::future<Iterator> when_each_n(F&& f, Iterator begin, std::size_t count)
     {
-        using future_type =
-            typename lcos::detail::future_iterator_traits<Iterator>::type;
+        using future_type = typename lcos::detail::future_iterator_traits<Iterator>::type;
 
         std::vector<future_type> values;
         values.reserve(count);
@@ -413,8 +393,7 @@ namespace pika {
 
         return pika::when_each(PIKA_FORWARD(F, f), values)
             .then(pika::launch::sync,
-                [begin = PIKA_MOVE(begin)](
-                    pika::future<void>&& fut) -> Iterator {
+                [begin = PIKA_MOVE(begin)](pika::future<void>&& fut) -> Iterator {
                     fut.get();    // rethrow exceptions, if any
                     return begin;
                 });
@@ -434,19 +413,17 @@ namespace pika {
     when_each(F&& f, Ts&&... ts)
     {
         using argument_type = std::tuple<traits::acquire_future_t<Ts>...>;
-        using frame_type =
-            detail::when_each_frame<argument_type, std::decay_t<F>>;
+        using frame_type = detail::when_each_frame<argument_type, std::decay_t<F>>;
 
         traits::acquire_future_disp func;
         argument_type values(func(PIKA_FORWARD(Ts, ts))...);
 
-        pika::intrusive_ptr<frame_type> p(new frame_type(
-            PIKA_MOVE(values), PIKA_FORWARD(F, f), sizeof...(Ts)));
+        pika::intrusive_ptr<frame_type> p(
+            new frame_type(PIKA_MOVE(values), PIKA_FORWARD(F, f), sizeof...(Ts)));
 
         p->template do_await<0>();
 
-        return pika::traits::future_access<typename frame_type::type>::create(
-            PIKA_MOVE(p));
+        return pika::traits::future_access<typename frame_type::type>::create(PIKA_MOVE(p));
     }
 }    // namespace pika
 #endif    // DOXYGEN
