@@ -48,8 +48,8 @@ void test_wait_each_from_list()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -99,8 +99,8 @@ void test_wait_each_from_list_iterators()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -152,8 +152,8 @@ void test_wait_each_n_from_list_iterators()
         PIKA_TEST_LT(id, n);
     };
 
-    auto callback_with_index_n = [n, &call_with_index_count](std::size_t idx,
-                                     pika::future<unsigned> fut) {
+    auto callback_with_index_n = [n, &call_with_index_count](
+                                     std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -204,8 +204,8 @@ void test_wait_each_one_future()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -214,10 +214,8 @@ void test_wait_each_one_future()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g =
-        pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g = pika::make_ready_future(static_cast<unsigned>(0));
 
     pika::wait_each(callback, std::move(f));
     pika::wait_each(callback_with_index, std::move(g));
@@ -243,8 +241,8 @@ void test_wait_each_two_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -253,14 +251,10 @@ void test_wait_each_two_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
 
     pika::wait_each(callback, std::move(f1), std::move(f2));
     pika::wait_each(callback_with_index, std::move(g1), std::move(g2));
@@ -288,8 +282,8 @@ void test_wait_each_three_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -298,22 +292,15 @@ void test_wait_each_three_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
 
     pika::wait_each(callback, std::move(f1), std::move(f2), std::move(f3));
-    pika::wait_each(
-        callback_with_index, std::move(g1), std::move(g2), std::move(g3));
+    pika::wait_each(callback_with_index, std::move(g1), std::move(g2), std::move(g3));
 
     PIKA_TEST_EQ(call_count, count);
     PIKA_TEST_EQ(call_with_index_count, count);
@@ -340,8 +327,8 @@ void test_wait_each_four_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -350,27 +337,18 @@ void test_wait_each_four_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> f4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g4 = pika::make_ready_future(static_cast<unsigned>(3));
 
+    pika::wait_each(callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4));
     pika::wait_each(
-        callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4));
-    pika::wait_each(callback_with_index, std::move(g1), std::move(g2),
-        std::move(g3), std::move(g4));
+        callback_with_index, std::move(g1), std::move(g2), std::move(g3), std::move(g4));
 
     PIKA_TEST_EQ(call_count, count);
     PIKA_TEST_EQ(call_with_index_count, count);
@@ -399,8 +377,8 @@ void test_wait_each_five_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -409,32 +387,22 @@ void test_wait_each_five_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> f4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> f5 =
-        pika::make_ready_future(static_cast<unsigned>(4));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> g5 =
-        pika::make_ready_future(static_cast<unsigned>(4));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> f5 = pika::make_ready_future(static_cast<unsigned>(4));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> g5 = pika::make_ready_future(static_cast<unsigned>(4));
 
-    pika::wait_each(callback, std::move(f1), std::move(f2), std::move(f3),
-        std::move(f4), std::move(f5));
+    pika::wait_each(
+        callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4), std::move(f5));
 
-    pika::wait_each(callback_with_index, std::move(g1), std::move(g2),
-        std::move(g3), std::move(g4), std::move(g5));
+    pika::wait_each(callback_with_index, std::move(g1), std::move(g2), std::move(g3), std::move(g4),
+        std::move(g5));
 
     PIKA_TEST_EQ(call_count, count);
     PIKA_TEST_EQ(call_with_index_count, count);
@@ -465,8 +433,8 @@ void test_wait_each_late_future()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -520,8 +488,8 @@ void test_wait_each_deferred_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -530,15 +498,11 @@ void test_wait_each_deferred_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{0});
-    pika::future<unsigned> f2 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{1});
+    pika::future<unsigned> f1 = pika::async(pika::launch::deferred, make_unsigned_slowly{0});
+    pika::future<unsigned> f2 = pika::async(pika::launch::deferred, make_unsigned_slowly{1});
 
-    pika::future<unsigned> g1 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{0});
-    pika::future<unsigned> g2 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{1});
+    pika::future<unsigned> g1 = pika::async(pika::launch::deferred, make_unsigned_slowly{0});
+    pika::future<unsigned> g2 = pika::async(pika::launch::deferred, make_unsigned_slowly{1});
 
     pika::wait_each(callback, std::move(f1), std::move(f2));
     pika::wait_each(callback_with_index, std::move(g1), std::move(g2));
