@@ -78,7 +78,7 @@ namespace pika::cuda::experimental::then_with_stream_detail {
                 std::make_exception_ptr(pika::exception(pika::error::unknown_error,
                     fmt::format(
                         "Getting event after CUDA stream transform failed with status {} ({})",
-                        status, whip::get_error_string(status)))));
+                        static_cast<int>(status), whip::get_error_string(status)))));
         }
     }
 
@@ -138,14 +138,8 @@ namespace pika::cuda::experimental::then_with_stream_detail {
     {
         using is_sender = void;
 
-        // nvcc 12.0 is not able to compile this with no_unique_address
-#if defined(PIKA_CUDA_VERSION) && PIKA_CUDA_VERSION >= 1200
-        std::decay_t<Sender> sender;
-        std::decay_t<F> f;
-#else
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<Sender> sender;
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<F> f;
-#endif
         cuda_scheduler sched;
 
         template <typename Sender_, typename F_>
@@ -208,14 +202,8 @@ namespace pika::cuda::experimental::then_with_stream_detail {
         template <typename Receiver>
         struct operation_state
         {
-            // nvcc 12.0 is not able to compile this with no_unique_address
-#if defined(PIKA_CUDA_VERSION) && PIKA_CUDA_VERSION >= 1200
-            std::decay_t<Receiver> receiver;
-            std::decay_t<F> f;
-#else
             PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
             PIKA_NO_UNIQUE_ADDRESS std::decay_t<F> f;
-#endif
             cuda_scheduler sched;
             std::optional<std::reference_wrapper<const cuda_stream>> stream;
 
@@ -556,8 +544,8 @@ namespace pika::cuda::experimental::then_with_stream_detail {
                 PIKA_FORWARD(Receiver, receiver), s.f, s.sched, s.sender);
         }
 
-        friend auto tag_invoke(
-            pika::execution::experimental::get_env_t, then_with_cuda_stream_sender_type const& s)
+        friend auto tag_invoke(pika::execution::experimental::get_env_t,
+            then_with_cuda_stream_sender_type const& s) noexcept
         {
             return pika::execution::experimental::get_env(s.sender);
         }
