@@ -32,24 +32,19 @@
 namespace pika::lcos::detail {
 
     template <typename Future, typename SourceState, typename DestinationState>
-    PIKA_FORCEINLINE void
-    transfer_result(SourceState&& src, DestinationState const& dest)
+    PIKA_FORCEINLINE void transfer_result(SourceState&& src, DestinationState const& dest)
     {
         pika::detail::try_catch_exception_ptr(
             [&]() {
                 traits::future_access<Future>::transfer_result(
-                    traits::future_access<Future>::create(
-                        PIKA_FORWARD(SourceState, src)),
-                    *dest);
+                    traits::future_access<Future>::create(PIKA_FORWARD(SourceState, src)), *dest);
             },
-            [&](std::exception_ptr ep) {
-                (*dest).set_exception(PIKA_MOVE(ep));
-            });
+            [&](std::exception_ptr ep) { (*dest).set_exception(PIKA_MOVE(ep)); });
     }
 
     template <typename Func, typename Future, typename Continuation>
-    void invoke_continuation_nounwrap(
-        Func& func, Future&& future, Continuation& cont, std::false_type)
+    void
+    invoke_continuation_nounwrap(Func& func, Future&& future, Continuation& cont, std::false_type)
     {
         pika::intrusive_ptr<Continuation> keep_alive(&cont);
         pika::detail::try_catch_exception_ptr(
@@ -58,8 +53,8 @@ namespace pika::lcos::detail {
     }
 
     template <typename Func, typename Future, typename Continuation>
-    void invoke_continuation_nounwrap(
-        Func& func, Future&& future, Continuation& cont, std::true_type)
+    void
+    invoke_continuation_nounwrap(Func& func, Future&& future, Continuation& cont, std::true_type)
     {
         pika::intrusive_ptr<Continuation> keep_alive(&cont);
         pika::detail::try_catch_exception_ptr(
@@ -71,41 +66,32 @@ namespace pika::lcos::detail {
     }
 
     template <typename Func, typename Future, typename Continuation>
-    std::enable_if_t<!traits::detail::is_unique_future<
-        util::detail::invoke_result_t<Func, Future>>::value>
+    std::enable_if_t<!traits::detail::is_unique_future<std::invoke_result_t<Func, Future>>::value>
     invoke_continuation(Func& func, Future&& future, Continuation& cont)
     {
-        using is_void =
-            std::is_void<util::detail::invoke_result_t<Func, Future>>;
+        using is_void = std::is_void<std::invoke_result_t<Func, Future>>;
 
         pika::scoped_annotation annotate(func);
-        invoke_continuation_nounwrap(
-            func, PIKA_FORWARD(Future, future), cont, is_void());
+        invoke_continuation_nounwrap(func, PIKA_FORWARD(Future, future), cont, is_void());
     }
 
     template <typename Func, typename Future, typename Continuation>
-    std::enable_if_t<traits::detail::is_unique_future<
-        util::detail::invoke_result_t<Func, Future>>::value>
+    std::enable_if_t<traits::detail::is_unique_future<std::invoke_result_t<Func, Future>>::value>
     invoke_continuation(Func& func, Future&& future, Continuation& cont)
     {
         pika::detail::try_catch_exception_ptr(
             [&]() {
-                using inner_future =
-                    util::detail::invoke_result_t<Func, Future>;
-                using inner_shared_state_ptr =
-                    traits::detail::shared_state_ptr_for_t<inner_future>;
+                using inner_future = std::invoke_result_t<Func, Future>;
+                using inner_shared_state_ptr = traits::detail::shared_state_ptr_for_t<inner_future>;
 
                 // take by value, as the future may go away immediately
                 inner_shared_state_ptr inner_state =
-                    traits::detail::get_shared_state(
-                        func(PIKA_FORWARD(Future, future)));
-                typename inner_shared_state_ptr::element_type* ptr =
-                    inner_state.get();
+                    traits::detail::get_shared_state(func(PIKA_FORWARD(Future, future)));
+                typename inner_shared_state_ptr::element_type* ptr = inner_state.get();
 
                 if (ptr == nullptr)
                 {
-                    PIKA_THROW_EXCEPTION(pika::error::no_state,
-                        "invoke_continuation",
+                    PIKA_THROW_EXCEPTION(pika::error::no_state, "invoke_continuation",
                         "the inner future has no valid shared state");
                 }
 
@@ -113,12 +99,10 @@ namespace pika::lcos::detail {
                 // its result to the new future.
                 pika::intrusive_ptr<Continuation> cont_(&cont);
                 ptr->execute_deferred();
-                ptr->set_on_completed(
-                    [inner_state = PIKA_MOVE(inner_state),
-                        cont_ = PIKA_MOVE(cont_)]() mutable -> void {
-                        return transfer_result<inner_future>(
-                            PIKA_MOVE(inner_state), PIKA_MOVE(cont_));
-                    });
+                ptr->set_on_completed([inner_state = PIKA_MOVE(inner_state),
+                                          cont_ = PIKA_MOVE(cont_)]() mutable -> void {
+                    return transfer_result<inner_future>(PIKA_MOVE(inner_state), PIKA_MOVE(cont_));
+                });
             },
             [&](std::exception_ptr ep) { cont.set_exception(PIKA_MOVE(ep)); });
     }
@@ -166,8 +150,8 @@ namespace pika::lcos::detail {
         using init_no_addref = typename base_type::init_no_addref;
 
         template <typename Func,
-            typename Enable = std::enable_if_t<
-                !std::is_same<std::decay_t<Func>, continuation>::value>>
+            typename Enable =
+                std::enable_if_t<!std::is_same<std::decay_t<Func>, continuation>::value>>
         // NOLINTNEXTLINE(bugprone-forwarding-reference-overload)
         continuation(Func&& f)
           : started_(false)
@@ -192,27 +176,22 @@ namespace pika::lcos::detail {
             invoke_continuation(f_, PIKA_MOVE(future), *this);
         }
 
-        void run_impl_nounwrap(
-            traits::detail::shared_state_ptr_for_t<Future>&& f)
+        void run_impl_nounwrap(traits::detail::shared_state_ptr_for_t<Future>&& f)
         {
-            using is_void =
-                std::is_void<util::detail::invoke_result_t<F, Future>>;
+            using is_void = std::is_void<std::invoke_result_t<F, Future>>;
 
             Future future = traits::future_access<Future>::create(PIKA_MOVE(f));
-            invoke_continuation_nounwrap(
-                f_, PIKA_MOVE(future), *this, is_void{});
+            invoke_continuation_nounwrap(f_, PIKA_MOVE(future), *this, is_void{});
         }
 
     public:
-        void run(traits::detail::shared_state_ptr_for_t<Future>&& f,
-            error_code& ec = throws)
+        void run(traits::detail::shared_state_ptr_for_t<Future>&& f, error_code& ec = throws)
         {
             {
                 std::lock_guard<mutex_type> l(mtx_);
                 if (started_)
                 {
-                    PIKA_THROWS_IF(ec, pika::error::task_already_started,
-                        "continuation::run",
+                    PIKA_THROWS_IF(ec, pika::error::task_already_started, "continuation::run",
                         "this task has already been started");
                     return;
                 }
@@ -225,16 +204,15 @@ namespace pika::lcos::detail {
                 ec = make_success_code();
         }
 
-        void run_nounwrap(traits::detail::shared_state_ptr_for_t<Future>&& f,
-            error_code& ec = throws)
+        void run_nounwrap(
+            traits::detail::shared_state_ptr_for_t<Future>&& f, error_code& ec = throws)
         {
             {
                 std::lock_guard<mutex_type> l(mtx_);
                 if (started_)
                 {
                     PIKA_THROWS_IF(ec, pika::error::task_already_started,
-                        "continuation::run_nounwrap",
-                        "this task has already been started");
+                        "continuation::run_nounwrap", "this task has already been started");
                     return;
                 }
                 started_ = true;
@@ -255,32 +233,28 @@ namespace pika::lcos::detail {
             invoke_continuation(f_, PIKA_MOVE(future), *this);
         }
 
-        void async_impl_nounwrap(
-            traits::detail::shared_state_ptr_for_t<Future>&& f)
+        void async_impl_nounwrap(traits::detail::shared_state_ptr_for_t<Future>&& f)
         {
-            using is_void =
-                std::is_void<util::detail::invoke_result_t<F, Future>>;
+            using is_void = std::is_void<std::invoke_result_t<F, Future>>;
 
             reset_id r(*this);
 
             Future future = traits::future_access<Future>::create(PIKA_MOVE(f));
-            invoke_continuation_nounwrap(
-                f_, PIKA_MOVE(future), *this, is_void{});
+            invoke_continuation_nounwrap(f_, PIKA_MOVE(future), *this, is_void{});
         }
 
     public:
         ///////////////////////////////////////////////////////////////////////
         template <typename Spawner>
-        void async(traits::detail::shared_state_ptr_for_t<Future>&& f,
-            Spawner&& spawner, error_code& ec = pika::throws)
+        void async(traits::detail::shared_state_ptr_for_t<Future>&& f, Spawner&& spawner,
+            error_code& ec = pika::throws)
         {
             {
                 std::unique_lock<mutex_type> l(this->mtx_);
                 if (started_)
                 {
                     l.unlock();
-                    PIKA_THROWS_IF(ec, pika::error::task_already_started,
-                        "continuation::async",
+                    PIKA_THROWS_IF(ec, pika::error::task_already_started, "continuation::async",
                         "this task has already been started");
                     return;
                 }
@@ -289,10 +263,8 @@ namespace pika::lcos::detail {
 
             pika::intrusive_ptr<continuation> this_(this);
             pika::detail::thread_description desc(f_, "async");
-            spawner(
-                [this_ = PIKA_MOVE(this_), f = PIKA_MOVE(f)]() mutable -> void {
-                    this_->async_impl(PIKA_MOVE(f));
-                },
+            spawner([this_ = PIKA_MOVE(this_),
+                        f = PIKA_MOVE(f)]() mutable -> void { this_->async_impl(PIKA_MOVE(f)); },
                 desc);
 
             if (&ec != &throws)
@@ -301,8 +273,8 @@ namespace pika::lcos::detail {
 
         ///////////////////////////////////////////////////////////////////////
         template <typename Spawner>
-        void async_nounwrap(traits::detail::shared_state_ptr_for_t<Future>&& f,
-            Spawner&& spawner, error_code& ec = pika::throws)
+        void async_nounwrap(traits::detail::shared_state_ptr_for_t<Future>&& f, Spawner&& spawner,
+            error_code& ec = pika::throws)
         {
             {
                 std::unique_lock<mutex_type> l(this->mtx_);
@@ -310,8 +282,7 @@ namespace pika::lcos::detail {
                 {
                     l.unlock();
                     PIKA_THROWS_IF(ec, pika::error::task_already_started,
-                        "continuation::async_nounwrap",
-                        "this task has already been started");
+                        "continuation::async_nounwrap", "this task has already been started");
                     return;
                 }
                 started_ = true;
@@ -356,14 +327,12 @@ namespace pika::lcos::detail {
 
                         l.unlock();
                         this->set_error(pika::error::future_cancelled,
-                            "continuation<Future, ContResult>::cancel",
-                            "future has been canceled");
+                            "continuation<Future, ContResult>::cancel", "future has been canceled");
                     }
                     else
                     {
                         l.unlock();
-                        PIKA_THROW_EXCEPTION(
-                            pika::error::future_can_not_be_cancelled,
+                        PIKA_THROW_EXCEPTION(pika::error::future_can_not_be_cancelled,
                             "continuation<Future, ContResult>::cancel",
                             "future can't be canceled at this time");
                     }
@@ -379,12 +348,10 @@ namespace pika::lcos::detail {
         ///////////////////////////////////////////////////////////////////////
         // TODO: Reduce duplication!
         template <typename Spawner, typename Policy>
-        void
-        attach(Future const& future, std::remove_reference_t<Spawner>& spawner,
+        void attach(Future const& future, std::remove_reference_t<Spawner>& spawner,
             Policy&& policy, error_code& /*ec*/ = throws)
         {
-            using shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<Future>;
+            using shared_state_ptr = traits::detail::shared_state_ptr_for_t<Future>;
 
             // bind an on_completed handler to this future which will invoke
             // the continuation
@@ -394,16 +361,14 @@ namespace pika::lcos::detail {
 
             if (ptr == nullptr)
             {
-                PIKA_THROW_EXCEPTION(pika::error::no_state,
-                    "continuation::attach",
+                PIKA_THROW_EXCEPTION(pika::error::no_state, "continuation::attach",
                     "the future to attach has no valid shared state");
             }
 
             ptr->execute_deferred();
             ptr->set_on_completed(
                 [this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
-                    policy = PIKA_FORWARD(Policy, policy),
-                    &spawner]() mutable -> void {
+                    policy = PIKA_FORWARD(Policy, policy), &spawner]() mutable -> void {
                     if (pika::detail::has_async_policy(policy))
                     {
                         this_->async(PIKA_MOVE(state), spawner);
@@ -416,12 +381,10 @@ namespace pika::lcos::detail {
         }
 
         template <typename Spawner, typename Policy>
-        void
-        attach(Future const& future, std::remove_reference_t<Spawner>&& spawner,
+        void attach(Future const& future, std::remove_reference_t<Spawner>&& spawner,
             Policy&& policy, error_code& /*ec*/ = throws)
         {
-            using shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<Future>;
+            using shared_state_ptr = traits::detail::shared_state_ptr_for_t<Future>;
 
             // bind an on_completed handler to this future which will invoke
             // the continuation
@@ -431,35 +394,31 @@ namespace pika::lcos::detail {
 
             if (ptr == nullptr)
             {
-                PIKA_THROW_EXCEPTION(pika::error::no_state,
-                    "continuation::attach",
+                PIKA_THROW_EXCEPTION(pika::error::no_state, "continuation::attach",
                     "the future to attach has no valid shared state");
             }
 
             ptr->execute_deferred();
-            ptr->set_on_completed(
-                [this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
-                    policy = PIKA_FORWARD(Policy, policy),
-                    spawner = PIKA_MOVE(spawner)]() mutable -> void {
-                    if (pika::detail::has_async_policy(policy))
-                    {
-                        this_->async(PIKA_MOVE(state), PIKA_MOVE(spawner));
-                    }
-                    else
-                    {
-                        this_->run(PIKA_MOVE(state));
-                    }
-                });
+            ptr->set_on_completed([this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
+                                      policy = PIKA_FORWARD(Policy, policy),
+                                      spawner = PIKA_MOVE(spawner)]() mutable -> void {
+                if (pika::detail::has_async_policy(policy))
+                {
+                    this_->async(PIKA_MOVE(state), PIKA_MOVE(spawner));
+                }
+                else
+                {
+                    this_->run(PIKA_MOVE(state));
+                }
+            });
         }
 
         ///////////////////////////////////////////////////////////////////////
         template <typename Spawner, typename Policy>
-        void attach_nounwrap(Future const& future,
-            std::remove_reference_t<Spawner>& spawner, Policy&& policy,
-            error_code& /*ec*/ = throws)
+        void attach_nounwrap(Future const& future, std::remove_reference_t<Spawner>& spawner,
+            Policy&& policy, error_code& /*ec*/ = throws)
         {
-            using shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<Future>;
+            using shared_state_ptr = traits::detail::shared_state_ptr_for_t<Future>;
 
             // bind an on_completed handler to this future which will invoke
             // the continuation
@@ -469,16 +428,14 @@ namespace pika::lcos::detail {
 
             if (ptr == nullptr)
             {
-                PIKA_THROW_EXCEPTION(pika::error::no_state,
-                    "continuation::attach_nounwrap",
+                PIKA_THROW_EXCEPTION(pika::error::no_state, "continuation::attach_nounwrap",
                     "the future to attach has no valid shared state");
             }
 
             ptr->execute_deferred();
             ptr->set_on_completed(
                 [this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
-                    policy = PIKA_FORWARD(Policy, policy),
-                    &spawner]() mutable -> void {
+                    policy = PIKA_FORWARD(Policy, policy), &spawner]() mutable -> void {
                     if (pika::detail::has_async_policy(policy))
                     {
                         this_->async_nounwrap(PIKA_MOVE(state), spawner);
@@ -491,12 +448,10 @@ namespace pika::lcos::detail {
         }
 
         template <typename Spawner, typename Policy>
-        void attach_nounwrap(Future const& future,
-            std::remove_reference_t<Spawner>&& spawner, Policy&& policy,
-            error_code& /*ec*/ = throws)
+        void attach_nounwrap(Future const& future, std::remove_reference_t<Spawner>&& spawner,
+            Policy&& policy, error_code& /*ec*/ = throws)
         {
-            using shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<Future>;
+            using shared_state_ptr = traits::detail::shared_state_ptr_for_t<Future>;
 
             // bind an on_completed handler to this future which will invoke
             // the continuation
@@ -506,26 +461,23 @@ namespace pika::lcos::detail {
 
             if (ptr == nullptr)
             {
-                PIKA_THROW_EXCEPTION(pika::error::no_state,
-                    "continuation::attach_nounwrap",
+                PIKA_THROW_EXCEPTION(pika::error::no_state, "continuation::attach_nounwrap",
                     "the future to attach has no valid shared state");
             }
 
             ptr->execute_deferred();
-            ptr->set_on_completed(
-                [this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
-                    policy = PIKA_FORWARD(Policy, policy),
-                    spawner = PIKA_MOVE(spawner)]() mutable -> void {
-                    if (pika::detail::has_async_policy(policy))
-                    {
-                        this_->async_nounwrap(
-                            PIKA_MOVE(state), PIKA_MOVE(spawner));
-                    }
-                    else
-                    {
-                        this_->run_nounwrap(PIKA_MOVE(state));
-                    }
-                });
+            ptr->set_on_completed([this_ = PIKA_MOVE(this_), state = PIKA_MOVE(state),
+                                      policy = PIKA_FORWARD(Policy, policy),
+                                      spawner = PIKA_MOVE(spawner)]() mutable -> void {
+                if (pika::detail::has_async_policy(policy))
+                {
+                    this_->async_nounwrap(PIKA_MOVE(state), PIKA_MOVE(spawner));
+                }
+                else
+                {
+                    this_->run_nounwrap(PIKA_MOVE(state));
+                }
+            });
         }
 
     protected:
@@ -534,14 +486,13 @@ namespace pika::lcos::detail {
         std::decay_t<F> f_;
     };
 
-    template <typename Allocator, typename Future, typename F,
-        typename ContResult>
+    template <typename Allocator, typename Future, typename F, typename ContResult>
     class continuation_allocator : public continuation<Future, F, ContResult>
     {
         using base_type = continuation<Future, F, ContResult>;
 
-        using other_allocator = typename std::allocator_traits<
-            Allocator>::template rebind_alloc<continuation_allocator>;
+        using other_allocator = typename std::allocator_traits<Allocator>::template rebind_alloc<
+            continuation_allocator>;
 
     public:
         using init_no_addref = typename base_type::init_no_addref;
@@ -554,8 +505,7 @@ namespace pika::lcos::detail {
         }
 
         template <typename Func>
-        continuation_allocator(
-            init_no_addref no_addref, other_allocator const& alloc, Func&& f)
+        continuation_allocator(init_no_addref no_addref, other_allocator const& alloc, Func&& f)
           : base_type(no_addref, PIKA_FORWARD(Func, f))
           , alloc_(alloc)
         {
@@ -576,13 +526,10 @@ namespace pika::lcos::detail {
 }    // namespace pika::lcos::detail
 
 namespace pika::traits::detail {
-    template <typename Future, typename F, typename ContResult,
-        typename Allocator>
-    struct shared_state_allocator<
-        lcos::detail::continuation<Future, F, ContResult>, Allocator>
+    template <typename Future, typename F, typename ContResult, typename Allocator>
+    struct shared_state_allocator<lcos::detail::continuation<Future, F, ContResult>, Allocator>
     {
-        using type = lcos::detail::continuation_allocator<Allocator, Future, F,
-            ContResult>;
+        using type = lcos::detail::continuation_allocator<Allocator, Future, F, ContResult>;
     };
 }    // namespace pika::traits::detail
 
@@ -594,19 +541,16 @@ namespace pika::lcos::detail {
     {
     private:
         template <typename Inner>
-        void on_inner_ready(
-            traits::detail::shared_state_ptr_for_t<Inner>&& inner_state)
+        void on_inner_ready(traits::detail::shared_state_ptr_for_t<Inner>&& inner_state)
         {
             transfer_result<Inner>(PIKA_MOVE(inner_state), this);
         }
 
         template <typename Outer>
-        void on_outer_ready(
-            traits::detail::shared_state_ptr_for_t<Outer>&& outer_state)
+        void on_outer_ready(traits::detail::shared_state_ptr_for_t<Outer>&& outer_state)
         {
             using inner_future = traits::future_traits_t<Outer>;
-            using inner_shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<inner_future>;
+            using inner_shared_state_ptr = traits::detail::shared_state_ptr_for_t<inner_future>;
 
             // Bind an on_completed handler to this future which will transfer
             // its result to the new future.
@@ -615,14 +559,12 @@ namespace pika::lcos::detail {
             pika::detail::try_catch_exception_ptr(
                 [&]() {
                     // if we get here, this future is ready
-                    Outer outer = traits::future_access<Outer>::create(
-                        PIKA_MOVE(outer_state));
+                    Outer outer = traits::future_access<Outer>::create(PIKA_MOVE(outer_state));
 
                     // take by value, as the future will go away immediately
                     inner_shared_state_ptr inner_state =
                         traits::detail::get_shared_state(outer.get());
-                    typename inner_shared_state_ptr::element_type* ptr =
-                        inner_state.get();
+                    typename inner_shared_state_ptr::element_type* ptr = inner_state.get();
 
                     if (ptr == nullptr)
                     {
@@ -632,17 +574,13 @@ namespace pika::lcos::detail {
                     }
 
                     ptr->execute_deferred();
-                    ptr->set_on_completed(
-                        [this_ = PIKA_MOVE(this_),
-                            inner_state =
-                                PIKA_MOVE(inner_state)]() mutable -> void {
-                            return this_->template on_inner_ready<inner_future>(
-                                PIKA_MOVE(inner_state));
-                        });
+                    ptr->set_on_completed([this_ = PIKA_MOVE(this_),
+                                              inner_state =
+                                                  PIKA_MOVE(inner_state)]() mutable -> void {
+                        return this_->template on_inner_ready<inner_future>(PIKA_MOVE(inner_state));
+                    });
                 },
-                [&](std::exception_ptr ep) {
-                    this->set_exception(PIKA_MOVE(ep));
-                });
+                [&](std::exception_ptr ep) { this->set_exception(PIKA_MOVE(ep)); });
         }
 
     public:
@@ -658,17 +596,14 @@ namespace pika::lcos::detail {
         template <typename Future>
         void attach(Future&& future)
         {
-            using outer_shared_state_ptr =
-                traits::detail::shared_state_ptr_for_t<Future>;
+            using outer_shared_state_ptr = traits::detail::shared_state_ptr_for_t<Future>;
 
             // Bind an on_completed handler to this future which will wait for
             // the inner future and will transfer its result to the new future.
             pika::intrusive_ptr<unwrap_continuation> this_(this);
 
-            outer_shared_state_ptr outer_state =
-                traits::detail::get_shared_state(future);
-            typename outer_shared_state_ptr::element_type* ptr =
-                outer_state.get();
+            outer_shared_state_ptr outer_state = traits::detail::get_shared_state(future);
+            typename outer_shared_state_ptr::element_type* ptr = outer_state.get();
 
             if (ptr == nullptr)
             {
@@ -679,10 +614,8 @@ namespace pika::lcos::detail {
 
             ptr->execute_deferred();
             ptr->set_on_completed(
-                [this_ = PIKA_MOVE(this_),
-                    outer_state = PIKA_MOVE(outer_state)]() mutable -> void {
-                    return this_->template on_outer_ready<Future>(
-                        PIKA_MOVE(outer_state));
+                [this_ = PIKA_MOVE(this_), outer_state = PIKA_MOVE(outer_state)]() mutable -> void {
+                    return this_->template on_outer_ready<Future>(PIKA_MOVE(outer_state));
                 });
         }
     };
@@ -692,8 +625,8 @@ namespace pika::lcos::detail {
     {
         using base_type = unwrap_continuation<ContResult>;
 
-        using other_allocator = typename std::allocator_traits<
-            Allocator>::template rebind_alloc<unwrap_continuation_allocator>;
+        using other_allocator = typename std::allocator_traits<Allocator>::template rebind_alloc<
+            unwrap_continuation_allocator>;
 
     public:
         using init_no_addref = typename base_type::init_no_addref;
@@ -703,8 +636,7 @@ namespace pika::lcos::detail {
         {
         }
 
-        unwrap_continuation_allocator(
-            init_no_addref no_addref, other_allocator const& alloc)
+        unwrap_continuation_allocator(init_no_addref no_addref, other_allocator const& alloc)
           : base_type(no_addref)
           , alloc_(alloc)
         {
@@ -726,11 +658,9 @@ namespace pika::lcos::detail {
 
 namespace pika::traits::detail {
     template <typename ContResult, typename Allocator>
-    struct shared_state_allocator<lcos::detail::unwrap_continuation<ContResult>,
-        Allocator>
+    struct shared_state_allocator<lcos::detail::unwrap_continuation<ContResult>, Allocator>
     {
-        using type =
-            lcos::detail::unwrap_continuation_allocator<Allocator, ContResult>;
+        using type = lcos::detail::unwrap_continuation_allocator<Allocator, ContResult>;
     };
 }    // namespace pika::traits::detail
 
@@ -742,29 +672,28 @@ namespace pika::lcos::detail {
         using base_allocator = Allocator;
         using result_type = future_unwrap_result_t<Future>;
 
-        using shared_state = traits::shared_state_allocator_t<
-            detail::unwrap_continuation<result_type>, base_allocator>;
+        using shared_state =
+            traits::shared_state_allocator_t<detail::unwrap_continuation<result_type>,
+                base_allocator>;
 
-        using other_allocator = typename std::allocator_traits<
-            base_allocator>::template rebind_alloc<shared_state>;
+        using other_allocator =
+            typename std::allocator_traits<base_allocator>::template rebind_alloc<shared_state>;
         using traits = std::allocator_traits<other_allocator>;
 
         using init_no_addref = typename shared_state::init_no_addref;
 
-        using unique_ptr = std::unique_ptr<shared_state,
-            pika::detail::allocator_deleter<other_allocator>>;
+        using unique_ptr =
+            std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
         other_allocator alloc(a);
-        unique_ptr p(traits::allocate(alloc, 1),
-            pika::detail::allocator_deleter<other_allocator>{alloc});
+        unique_ptr p(
+            traits::allocate(alloc, 1), pika::detail::allocator_deleter<other_allocator>{alloc});
 
         traits::construct(alloc, p.get(), init_no_addref{}, alloc);
 
         // create a continuation
-        pika::traits::detail::shared_state_ptr_t<result_type> result(
-            p.release(), false);
-        static_cast<shared_state*>(result.get())
-            ->attach(PIKA_FORWARD(Future, future));
+        pika::traits::detail::shared_state_ptr_t<result_type> result(p.release(), false);
+        static_cast<shared_state*>(result.get())->attach(PIKA_FORWARD(Future, future));
         return result;
     }
 
@@ -772,8 +701,8 @@ namespace pika::lcos::detail {
     inline traits::detail::shared_state_ptr_t<future_unwrap_result_t<Future>>
     unwrap_impl(Future&& future, error_code& ec)
     {
-        return unwrap_impl_alloc(pika::detail::internal_allocator<>{},
-            PIKA_FORWARD(Future, future), ec);
+        return unwrap_impl_alloc(
+            pika::detail::internal_allocator<>{}, PIKA_FORWARD(Future, future), ec);
     }
 
     template <typename Allocator, typename Future>
