@@ -18,8 +18,7 @@ namespace pika::detail {
         runtime* rt = get_runtime_ptr();
         if (rt == nullptr)
         {
-            PIKA_THROW_EXCEPTION(pika::error::invalid_status,
-                "pika::detail::get_locality_name",
+            PIKA_THROW_EXCEPTION(pika::error::invalid_status, "pika::detail::get_locality_name",
                 "the runtime system is not operational at this point");
             return "";
         }
