@@ -57,12 +57,10 @@ namespace pika::threads::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    thread_manager::thread_manager(pika::util::runtime_configuration& rtcfg,
-        notification_policy_type& notifier,
-        network_background_callback_type network_background_callback)
+    thread_manager::thread_manager(
+        pika::util::runtime_configuration& rtcfg, notification_policy_type& notifier)
       : rtcfg_(rtcfg)
       , notifier_(notifier)
-      , network_background_callback_(network_background_callback)
     {
         using std::placeholders::_1;
         using std::placeholders::_3;
@@ -85,8 +83,6 @@ namespace pika::threads::detail {
         size_t num_pools = rp.get_num_pools();
         std::size_t thread_offset = 0;
 
-        std::size_t max_background_threads = pika::detail::get_entry_as<std::size_t>(
-            rtcfg_, "pika.max_background_threads", (std::numeric_limits<std::size_t>::max)());
         std::size_t const max_idle_loop_count = pika::detail::get_entry_as<std::int64_t>(
             rtcfg_, "pika.max_idle_loop_count", PIKA_IDLE_LOOP_COUNT_MAX);
         std::size_t const max_busy_loop_count = pika::detail::get_entry_as<std::int64_t>(
@@ -147,8 +143,7 @@ namespace pika::threads::detail {
 
             thread_pool_init_parameters thread_pool_init(name, i, scheduler_mode,
                 num_threads_in_pool, thread_offset, notifier_, rp.get_affinity_data(),
-                network_background_callback_, max_background_threads, max_idle_loop_count,
-                max_busy_loop_count);
+                max_idle_loop_count, max_busy_loop_count);
 
             std::size_t numa_sensitive =
                 pika::detail::get_entry_as<std::size_t>(rtcfg_, "pika.numa_sensitive", 0);
@@ -584,19 +579,6 @@ namespace pika::threads::detail {
         return mask;
     }
 
-    std::int64_t thread_manager::get_background_thread_count()
-    {
-        std::int64_t total_count = 0;
-        std::lock_guard<mutex_type> lk(mtx_);
-
-        for (auto& pool_iter : pools_)
-        {
-            total_count += pool_iter->get_background_thread_count();
-        }
-
-        return total_count;
-    }
-
     ///////////////////////////////////////////////////////////////////////////
     // Enumerate all matching threads
     bool thread_manager::enumerate_threads(
