@@ -9,6 +9,7 @@
 #include <fmt/ostream.h>
 #include <fmt/printf.h>
 
+#include <chrono>
 #include <cstddef>
 #include <cstdint>
 #include <iostream>
@@ -25,16 +26,15 @@ namespace pika::util {
             return res;
         }
 
-        void add_time(std::string const& test_name, std::string const& executor,
-            double time)
+        void add_time(std::string const& test_name, std::string const& executor, double time)
         {
             times().add(test_name, executor, time);
         }
 
     }    // namespace detail
 
-    void perftests_report(std::string const& name, std::string const& exec,
-        const std::size_t steps, detail::function<void(void)>&& test)
+    void perftests_report(std::string const& name, std::string const& exec, const std::size_t steps,
+        detail::function<void(void)>&& test)
     {
         if (steps == 0)
             return;
@@ -50,8 +50,7 @@ namespace pika::util {
             test();
             // default is in seconds
             auto time =
-                std::chrono::duration_cast<std::chrono::duration<double>>(
-                    timer::now() - start);
+                std::chrono::duration_cast<std::chrono::duration<double>>(timer::now() - start);
             detail::add_time(name, exec, time.count());
         }
     }
@@ -64,9 +63,8 @@ namespace pika::util {
     void print_cdash_timing(const char* name, double time)
     {
         fmt::print(std::cout,
-            "<DartMeasurement name=\"{}\" "
-            "type=\"numeric/double\">{}</DartMeasurement>\n",
-            name, time);
+            "<DartMeasurement name=\"{}\" type=\"numeric/double\">{}</DartMeasurement>\n", name,
+            time);
     }
 
     void print_cdash_timing(const char* name, std::uint64_t time)
